diff --git a/auxdir/libtool.m4 b/auxdir/libtool.m4
index ee80844b619f4e8689086457c4807c40fe238784..26cc05f1088d6686cd0e492ff010d318f4da3ffb 100644
--- a/auxdir/libtool.m4
+++ b/auxdir/libtool.m4
@@ -614,7 +614,7 @@ m4_popdef([AS_MESSAGE_LOG_FD])])])# _LT_GENERATED_FILE_INIT
 # LT_OUTPUT
 # ---------
 # This macro allows early generation of the libtool script (before
-# AC_OUTPUT is called), incase it is used in configure for compilation
+# AC_OUTPUT is called), in case it is used in configure for compilation
 # tests.
 AC_DEFUN([LT_OUTPUT],
 [: ${CONFIG_LT=./config.lt}
diff --git a/auxdir/ltmain.sh b/auxdir/ltmain.sh
index a736cf994256132aefd49c1f11118ad7ba31d924..c341e5a6275742b8413ecd2ff86bb8c11a3c435f 100644
--- a/auxdir/ltmain.sh
+++ b/auxdir/ltmain.sh
@@ -854,7 +854,7 @@ func_mkdir_p ()
       # While some portion of DIR does not yet exist...
       while test ! -d "$_G_directory_path"; do
         # ...make a list in topmost first order.  Use a colon delimited
-	# list incase some portion of path contains whitespace.
+	# list in case some portion of path contains whitespace.
         _G_dir_list=$_G_directory_path:$_G_dir_list
 
         # If the last portion added has no slash in it, the list is done
diff --git a/src/common/assoc_mgr.c b/src/common/assoc_mgr.c
index 8b0134e25b04d3739da9b046d7fa19da7ff3c722..fb942081895d0ef48ad9e46147e20c9bcf1458f3 100644
--- a/src/common/assoc_mgr.c
+++ b/src/common/assoc_mgr.c
@@ -2525,7 +2525,7 @@ extern int assoc_mgr_fill_in_user(void *db_conn, slurmdb_user_rec_t *user,
 	if (user_pptr)
 		*user_pptr = found_user;
 
-	/* create coord_accts just incase the list does not exist */
+	/* create coord_accts just in case the list does not exist */
 	if (!found_user->coord_accts)
 		found_user->coord_accts =
 			list_create(slurmdb_destroy_coord_rec);
diff --git a/src/common/assoc_mgr.h b/src/common/assoc_mgr.h
index efaeac319beafac3752e509606f5c74365aacef4..80b06fe8c8148abe14cd8d334bcb49395ac13799 100644
--- a/src/common/assoc_mgr.h
+++ b/src/common/assoc_mgr.h
@@ -391,7 +391,7 @@ extern void assoc_mgr_remove_assoc_usage(slurmdb_assoc_rec_t *assoc);
 extern void assoc_mgr_remove_qos_usage(slurmdb_qos_rec_t *qos);
 
 /*
- * Dump the state information of the association mgr just incase the
+ * Dump the state information of the association mgr just in case the
  * database isn't up next time we run.
  */
 extern int dump_assoc_mgr_state(char *state_save_location);
diff --git a/src/common/hostlist.c b/src/common/hostlist.c
index 447af744c7c560f2bd80fdbfff97e23147265025..c8ce94e829ff4a103513e0423ce2c5fa1754eb50 100644
--- a/src/common/hostlist.c
+++ b/src/common/hostlist.c
@@ -1101,7 +1101,7 @@ static int hostrange_hn_within(hostrange_t hr, hostname_t hn)
 			strncat(hn->prefix, hn->suffix, ldiff);
 			/* Now adjust the suffix of the hostname object. */
 			hn->suffix += ldiff;
-			/* And the numeric representation just incase
+			/* And the numeric representation just in case
 			 * whatever we just tacked on to the prefix
 			 * had something other than 0 in it.
 			 *
diff --git a/src/common/slurm_persist_conn.c b/src/common/slurm_persist_conn.c
index 1806ae76806d02155172a250789d014461468bf3..6d2debdec426696141cf67a0276b5bb2991a8e89 100644
--- a/src/common/slurm_persist_conn.c
+++ b/src/common/slurm_persist_conn.c
@@ -958,7 +958,7 @@ extern int slurm_persist_msg_unpack(slurm_persist_conn_t *persist_conn,
 		resp_msg->data = msg.data;
 	}
 
-	/* Here we transfer the auth_cred to the persist_conn just incase in the
+	/* Here we transfer the auth_cred to the persist_conn just in case in the
 	 * future we need to use it in some way to verify things for messages
 	 * that don't have on that will follow on the connection.
 	 */
diff --git a/src/common/slurm_protocol_api.c b/src/common/slurm_protocol_api.c
index 4e51b046b94a60fc926c24373c1c9fbe398cff01..80488042c039eff728fa56a9dad5d75a7c08f017 100644
--- a/src/common/slurm_protocol_api.c
+++ b/src/common/slurm_protocol_api.c
@@ -3621,7 +3621,7 @@ int slurm_receive_msg_and_forward(int fd, slurm_addr_t *orig_addr,
 	/*
 	 * header.orig_addr will be set to where the first message
 	 * came from if this is a forward else we set the
-	 * header.orig_addr to our addr just incase we need to send it off.
+	 * header.orig_addr to our addr just in case we need to send it off.
 	 */
 	if (header.orig_addr.sin_addr.s_addr != 0) {
 		memcpy(&msg->orig_addr, &header.orig_addr, sizeof(slurm_addr_t));
diff --git a/src/plugins/accounting_storage/mysql/as_mysql_cluster.c b/src/plugins/accounting_storage/mysql/as_mysql_cluster.c
index 07cceb2e24c15a08cbf98a34576656fc17d3d34e..dbdd60da93f902acff6f32219a6a6ec5dab0b30a 100644
--- a/src/plugins/accounting_storage/mysql/as_mysql_cluster.c
+++ b/src/plugins/accounting_storage/mysql/as_mysql_cluster.c
@@ -1455,7 +1455,7 @@ extern int as_mysql_fini_ctld(mysql_conn_t *mysql_conn,
 		return ESLURM_DB_CONNECTION;
 
 	/* Here we need to check make sure we are updating the entry
-	   correctly just incase the backup has already gained
+	   correctly just in case the backup has already gained
 	   control.  If we check the ip and port it is a pretty safe
 	   bet we have the right ctld.
 	*/
diff --git a/src/plugins/launch/poe/launch_poe.c b/src/plugins/launch/poe/launch_poe.c
index 93a1bdf5e16cb3ee171a60a5bd0f495dec8ab79d..aac210cddd08e6de6e6fdb97d8bde3d763311040 100644
--- a/src/plugins/launch/poe/launch_poe.c
+++ b/src/plugins/launch/poe/launch_poe.c
@@ -666,7 +666,7 @@ extern int launch_p_create_job_step(srun_job_t *job, bool use_all_cpus,
 		 * purpose.  It makes it so each task has a separate
 		 * line. */
 		setenv("MP_STDOUTMODE", "unordered", 1);
-		/* Just incase we didn't specify a file in srun. */
+		/* Just in case we didn't specify a file in srun. */
 		setenv("SLURM_ARBITRARY_NODELIST", opt.nodelist, 1);
 	} else {
 		/* Since poe doesn't need to know about the partition and it
diff --git a/src/plugins/launch/runjob/launch_runjob.c b/src/plugins/launch/runjob/launch_runjob.c
index 1998c00e6bccbfb16153a1aac9b408c9702a778a..7297ab48ff4307a153208e058f8f5de992b8fb2e 100644
--- a/src/plugins/launch/runjob/launch_runjob.c
+++ b/src/plugins/launch/runjob/launch_runjob.c
@@ -312,7 +312,7 @@ extern int launch_p_setup_srun_opt(char **rest)
 		}
 	}
 
-	/* We need to do +2 here just incase multi-prog is needed (we
+	/* We need to do +2 here just in case multi-prog is needed (we
 	 * add an extra argv on so just make space for it). */
 	opt.argv = (char **) xmalloc((opt.argc + command_pos + 2) *
 		   sizeof(char *));
diff --git a/src/plugins/launch/slurm/launch_slurm.c b/src/plugins/launch/slurm/launch_slurm.c
index c90fa7e17910c510f7b3e86ac57a3e0e00f49863..5a8104d12e5974fe3d7b314ab4b2aa1a5b432dee 100644
--- a/src/plugins/launch/slurm/launch_slurm.c
+++ b/src/plugins/launch/slurm/launch_slurm.c
@@ -468,7 +468,7 @@ extern int launch_p_setup_srun_opt(char **rest)
 	if (opt.debugger_test && opt.parallel_debug)
 		MPIR_being_debugged  = 1;
 
-	/* We need to do +2 here just incase multi-prog is needed (we
+	/* We need to do +2 here just in case multi-prog is needed (we
 	   add an extra argv on so just make space for it).
 	*/
 	opt.argv = (char **) xmalloc((opt.argc + 2) * sizeof(char *));
diff --git a/src/plugins/select/alps/select_alps.c b/src/plugins/select/alps/select_alps.c
index 1b4e92eacf98683c1e3cf86c32f1b2e2540825de..7ce902dd8876c76435147785a20b4adad1e24cb3 100644
--- a/src/plugins/select/alps/select_alps.c
+++ b/src/plugins/select/alps/select_alps.c
@@ -940,7 +940,7 @@ extern void select_p_ba_init(node_info_msg_t *node_info_ptr, bool sanity_check)
 		/* init the rest of the dim sizes. All current (2011)
 		 * XT/XE installations have a maximum dimension of 3,
 		 * smaller systems deploy a 2D Torus which has no
-		 * connectivity in X-dimension.  Just incase they
+		 * connectivity in X-dimension.  Just in case they
 		 * decide to change it where we only get 2 instead of
 		 * 3 we will initialize it later. */
 		for (i = 1; i < dims; i++)
diff --git a/src/plugins/select/bluegene/ba_bgq/block_allocator.c b/src/plugins/select/bluegene/ba_bgq/block_allocator.c
index 1801a1ceae5e0722c9f1c96132dc09625a9cdc2b..f48fd29f4fcfe786771fda3a0ca881225dce71c5 100644
--- a/src/plugins/select/bluegene/ba_bgq/block_allocator.c
+++ b/src/plugins/select/bluegene/ba_bgq/block_allocator.c
@@ -260,7 +260,7 @@ extern void ba_create_system()
 					ba_setup_mp(ba_mp, true, false);
 					ba_mp->state = NODE_STATE_IDLE;
 					/* This might get changed
-					   later, but just incase set
+					   later, but just in case set
 					   it up here.
 					*/
 					ba_mp->index = i++;
diff --git a/src/plugins/select/bluegene/bg_dynamic_block.c b/src/plugins/select/bluegene/bg_dynamic_block.c
index 4f94a73cac78520bdfc7b4b732364f1f4c48e3bd..47a75a7e73dd58b04492126549735dab385b16fe 100644
--- a/src/plugins/select/bluegene/bg_dynamic_block.c
+++ b/src/plugins/select/bluegene/bg_dynamic_block.c
@@ -82,7 +82,7 @@ extern List create_dynamic_block(List block_list,
 	memset(&blockreq, 0, sizeof(select_ba_request_t));
 	memcpy(start_geo, request->geometry, sizeof(start_geo));
 
-	/* We need to lock this just incase a blocks_overlap is called
+	/* We need to lock this just in case a blocks_overlap is called
 	   which will in turn reset and set the system as it sees fit.
 	*/
 	slurm_mutex_lock(&block_state_mutex);
diff --git a/src/plugins/select/bluegene/bl_bgq/bridge_linker.cc b/src/plugins/select/bluegene/bl_bgq/bridge_linker.cc
index 045943fa8276804e4a4c85e890cfeef4a11ce3b4..cf2ad6b5fda81beac0bab03b57f35dffb1cc3127 100644
--- a/src/plugins/select/bluegene/bl_bgq/bridge_linker.cc
+++ b/src/plugins/select/bluegene/bl_bgq/bridge_linker.cc
@@ -862,7 +862,7 @@ extern int bridge_block_boot(bg_record_t *bg_record)
 		debug("booting block %s", bg_record->bg_block_id);
 		Block::initiateBoot(bg_record->bg_block_id);
 		/* Set this here just to make sure we know we
-		   are suppose to be booting.  Just incase the
+		   are suppose to be booting.  Just in case the
 		   block goes free before we notice we are
 		   configuring.
 		*/
diff --git a/src/plugins/select/bluegene/select_bluegene.c b/src/plugins/select/bluegene/select_bluegene.c
index 2fec737e0cbfd2bb3e4586886b4a77791c81490d..7c9f10187fdb04a20ab77569bc1b18290a861d92 100644
--- a/src/plugins/select/bluegene/select_bluegene.c
+++ b/src/plugins/select/bluegene/select_bluegene.c
@@ -1699,7 +1699,7 @@ extern int select_p_job_ready(struct job_record *job_ptr)
 			} else if (!bg_record->free_cnt
 				   && (uid == job_ptr->user_id)
 				   && (bg_record->state == BG_BLOCK_INITED)) {
-				/* Clear the state just incase we
+				/* Clear the state just in case we
 				 * missed it somehow. */
 				job_ptr->job_state &= (~JOB_CONFIGURING);
 				last_job_update = time(NULL);
diff --git a/src/slurmctld/controller.c b/src/slurmctld/controller.c
index 43163b544475dcdc30a55129667c31c713440662..d76a48b2aa2060d04d97dcaf7528a884e6d60f68 100644
--- a/src/slurmctld/controller.c
+++ b/src/slurmctld/controller.c
@@ -272,7 +272,7 @@ int main(int argc, char **argv)
 
 	/* Verify clustername from conf matches value in spool dir
 	 * exit if inconsistent to protect state files from corruption.
-	 * This needs to be done before we kill the old one just incase we
+	 * This needs to be done before we kill the old one just in case we
 	 * fail. */
 	create_clustername_file = _verify_clustername();
 
diff --git a/src/slurmctld/job_mgr.c b/src/slurmctld/job_mgr.c
index 8a4d864484a6d306501d337badb4aaea4f8cfda0..701f01da707b10810106f4ab357209af69d7ed95 100644
--- a/src/slurmctld/job_mgr.c
+++ b/src/slurmctld/job_mgr.c
@@ -2199,7 +2199,7 @@ static int _load_job_state(Buf buffer, uint16_t protocol_version)
 			job_ptr->qos_id = qos_rec.id;
 	}
 
-	/* do this after the format string just incase for some
+	/* do this after the format string just in case for some
 	 * reason the tres_alloc_str is NULL but not the fmt_str */
 	if (job_ptr->tres_alloc_str)
 		assoc_mgr_set_tres_cnt_array(
@@ -9396,7 +9396,7 @@ static void _pack_default_job_details(struct job_record *job_ptr,
 				pack32((uint32_t) 0, buffer);
 			} else if (job_ptr->node_cnt_wag) {
 				/* This should catch everything else, but
-				 * just incase this is 0 (startup or
+				 * just in case this is 0 (startup or
 				 * whatever) we will keep the rest of
 				 * this if statement around.
 				 */
@@ -9548,7 +9548,7 @@ static void _pack_default_job_details(struct job_record *job_ptr,
 				pack32((uint32_t) 0, buffer);
 			} else if (job_ptr->node_cnt_wag) {
 				/* This should catch everything else, but
-				 * just incase this is 0 (startup or
+				 * just in case this is 0 (startup or
 				 * whatever) we will keep the rest of
 				 * this if statement around.
 				 */
diff --git a/src/slurmctld/step_mgr.c b/src/slurmctld/step_mgr.c
index 28de560f430d06e1168686500971c86e7ae1b943..ff0d634e2d16d9ae6c648d07a6765d399a4d98c8 100644
--- a/src/slurmctld/step_mgr.c
+++ b/src/slurmctld/step_mgr.c
@@ -3417,7 +3417,7 @@ extern int step_partial_comp(step_complete_msg_t *req, uid_t uid,
 
 	/* FIXME: It was changed in 16.05.3 to make the extern step
 	 * at the beginning of the job, so this isn't really needed
-	 * anymore, but just incase there were steps out on the nodes
+	 * anymore, but just in case there were steps out on the nodes
 	 * during an upgrade this was left in.  It can probably be
 	 * taken out in future releases though.
 	 */
diff --git a/src/slurmd/slurmd/req.c b/src/slurmd/slurmd/req.c
index bb94599baec7c7cd7eb0f635990676306413a746..5dc8f9be45bca5b3a9e480029d50c774a96874a8 100644
--- a/src/slurmd/slurmd/req.c
+++ b/src/slurmd/slurmd/req.c
@@ -923,7 +923,7 @@ _forkexec_slurmstepd(uint16_t type, void *req,
 		}
 
 		/*
-		 * Just incase we (or someone we are linking to)
+		 * Just in case we (or someone we are linking to)
 		 * opened a file and didn't do a close on exec.  This
 		 * is needed mostly to protect us against libs we link
 		 * to that don't set the flag as we should already be
diff --git a/src/slurmdbd/proc_req.c b/src/slurmdbd/proc_req.c
index 3e289042be8f15b7705c1ab42f7acb65b75ea2e1..c84d60686b56f97db7136fa69035c308f5e7b375 100644
--- a/src/slurmdbd/proc_req.c
+++ b/src/slurmdbd/proc_req.c
@@ -1828,7 +1828,7 @@ static int  _job_complete(slurmdbd_conn_t *slurmdbd_conn,
 	if (rc && errno == 740) /* meaning data is already there */
 		rc = SLURM_SUCCESS;
 
-	/* just incase this gets set we need to clear it */
+	/* just in case this gets set we need to clear it */
 	xfree(job.wckey);
 
 	if (!slurmdbd_conn->conn->rem_port) {
@@ -1912,7 +1912,7 @@ static int  _job_suspend(slurmdbd_conn_t *slurmdbd_conn,
 	if (rc && errno == 740) /* meaning data is already there */
 		rc = SLURM_SUCCESS;
 
-	/* just incase this gets set we need to clear it */
+	/* just in case this gets set we need to clear it */
 	xfree(job.wckey);
 end_it:
 	*out_buffer = slurm_persist_make_rc_msg(slurmdbd_conn->conn,
@@ -2584,7 +2584,7 @@ static void _process_job_start(slurmdbd_conn_t *slurmdbd_conn,
 	id_rc_msg->job_id = job.job_id;
 	id_rc_msg->db_index = job.db_index;
 
-	/* just incase job.wckey was set because we didn't send one */
+	/* just in case job.wckey was set because we didn't send one */
 	if (!job_start_msg->wckey)
 		xfree(job.wckey);
 
@@ -3372,7 +3372,7 @@ static int  _step_complete(slurmdbd_conn_t *slurmdbd_conn,
 
 	if (rc && errno == 740) /* meaning data is already there */
 		rc = SLURM_SUCCESS;
-	/* just incase this gets set we need to clear it */
+	/* just in case this gets set we need to clear it */
 	xfree(job.wckey);
 
 	if (!slurmdbd_conn->conn->rem_port) {
@@ -3447,7 +3447,7 @@ static int  _step_start(slurmdbd_conn_t *slurmdbd_conn,
 	if (rc && errno == 740) /* meaning data is already there */
 		rc = SLURM_SUCCESS;
 
-	/* just incase this gets set we need to clear it */
+	/* just in case this gets set we need to clear it */
 	xfree(job.wckey);
 
 	if (!slurmdbd_conn->conn->rem_port) {
diff --git a/src/smap/configure_functions.c b/src/smap/configure_functions.c
index 4454c5fde4ca961e6df6cbe2609f95a70f72327b..ffa9a6304753563405507cacbcc8cfb879059fc3 100644
--- a/src/smap/configure_functions.c
+++ b/src/smap/configure_functions.c
@@ -172,7 +172,7 @@ static int _full_request(select_ba_request_t *request,
 	/*
 	 * Here is where we do the allocating of the partition.
 	 * It will send a request back which we will throw into
-	 * a list just incase we change something later.
+	 * a list just in case we change something later.
 	 */
 	if (!bg_configure_new_ba_request(request)) {
 		memset(error_string, 0, 255);
diff --git a/src/sview/sview.c b/src/sview/sview.c
index d5a457d08d5409f605a5d853f9d70d467ce58a2d..794197e625cd3399091c1559d49d07b4fb57cdce 100644
--- a/src/sview/sview.c
+++ b/src/sview/sview.c
@@ -1331,7 +1331,7 @@ static GtkWidget *_create_cluster_combo(void)
 	if (list_count(cluster_list) > 1)
 		model = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_POINTER);
 
-	/* Set up the working_cluster_rec just incase we are on a node
+	/* Set up the working_cluster_rec just in case we are on a node
 	   that doesn't technically belong to a cluster (like
 	   the node running the slurmdbd).
 	*/
diff --git a/src/plugins/accounting_storage/mysql/as_mysql_resv.c b/src/plugins/accounting_storage/mysql/as_mysql_resv.c
index b7e01cdbf2bf4e5235ada0a468e13c13b454461a..8fdec7fc978de183934d7b58a38f8a97c8c62846 100644
--- a/src/plugins/accounting_storage/mysql/as_mysql_resv.c
+++ b/src/plugins/accounting_storage/mysql/as_mysql_resv.c
@@ -343,7 +343,7 @@ try_again:
 		      resv->time_start_prev, resv->cluster);
 		if (!set && resv->time_end) {
 			/* This should never really happen,
-			   but just incase the controller and the
+			   but just in case the controller and the
 			   database get out of sync we check
 			   to see if there is a reservation
 			   not deleted that hasn't ended yet. */
@@ -407,7 +407,7 @@ try_again:
 
 	_setup_resv_limits(resv, &cols, &vals, &extra);
 	/* use start below instead of resv->time_start_prev
 	 * just incase we have a different one from being out
 	 * of sync
 	 */
 	if ((start > now) || !set) {
@@ -407,7 +407,7 @@ try_again:
 	_setup_resv_limits(resv, &cols, &vals, &extra);
 	/* use start below instead of resv->time_start_prev
-	 * just incase we have a different one from being out
+	 * just in case we have a different one from being out
 	 * of sync
 	 */
diff --git a/src/plugins/select/bluegene/bg_core.c b/src/plugins/select/bluegene/bg_core.c
index 2c679db6012327577298dabc34ed26fdc0d48090..8c1082ef466495cd050eb840f0c022f7467fcb36 100644
--- a/src/plugins/select/bluegene/bg_core.c
+++ b/src/plugins/select/bluegene/bg_core.c
@@ -204,7 +204,7 @@ static void *_track_freeing_blocks(void *args)
 		bridge_status_update_block_list_state(track_list);
 
 		list_iterator_reset(itr);
 		/* just incase this changes from the update function */
 		track_cnt = list_count(track_list);
 		while ((bg_record = list_next(itr))) {
 			if (bg_record->magic != BLOCK_MAGIC) {
@@ -337,7 +337,7 @@ extern void bg_requeue_job(uint32_t job_id, bool wait_for_start,
 
 	/* Wait for the slurmd to begin the batch script, slurm_fail_job()
 	   is a no-op if issued prior to the script initiation do
-	   clean up just incase the fail job isn't ran. */
+	   clean up just in case the fail job isn't ran. */
 	if (wait_for_start)
 		sleep(2);
 
@@ -465,7 +465,7 @@ extern int bg_free_block(bg_record_t *bg_record, bool wait, bool locked)
 		*/
 		if (bg_record->state & BG_BLOCK_ERROR_FLAG) {
 			/* This will set the state to ERROR(Free)
 			 * just incase the state was ERROR(SOMETHING ELSE) */
 			bg_record->state = BG_BLOCK_ERROR_FLAG;
 			break;
 		} else if (!wait || (count >= 3))
@@ -204,7 +204,7 @@ static void *_track_freeing_blocks(void *args)
 
 		list_iterator_reset(itr);
-		/* just incase this changes from the update function */
+		/* just in case this changes from the update function */
 		track_cnt = list_count(track_list);
 		while ((bg_record = list_next(itr))) {
@@ -465,7 +465,7 @@ extern int bg_free_block(bg_record_t *bg_record, bool wait, bool locked)
 		if (bg_record->state & BG_BLOCK_ERROR_FLAG) {
 			/* This will set the state to ERROR(Free)
-			 * just incase the state was ERROR(SOMETHING ELSE) */
+			 * just in case the state was ERROR(SOMETHING ELSE) */
 			bg_record->state = BG_BLOCK_ERROR_FLAG;
 			break;
diff --git a/src/plugins/select/bluegene/bg_job_run.c b/src/plugins/select/bluegene/bg_job_run.c
index c296ef5f59241582c23986d93e784eb198921093..1c3f9702aedc56551bd62d73a141f7806d0b720a 100644
--- a/src/plugins/select/bluegene/bg_job_run.c
+++ b/src/plugins/select/bluegene/bg_job_run.c
@@ -569,7 +569,7 @@ no_reboot:
 		   the batch script, slurm_fail_job()
 		   is a no-op if issued prior
 		   to the script initiation do clean up just
-		   incase the fail job isn't ran */
+		   in case the fail job isn't ran */
 		(void) slurm_fail_job(req_job_id, JOB_BOOT_FAIL);
 	}
 }
@@ -762,7 +762,7 @@ extern int start_job(struct job_record *job_ptr)
 
 	if (!block_ptr_exist_in_list(bg_lists->booted, bg_record))
 		list_push(bg_lists->booted, bg_record);
 	/* Just incase something happens to free this block before we
 	   start the job we will make it so this job doesn't get blown
 	   away.
 	*/
@@ -762,7 +762,7 @@ extern int start_job(struct job_record *job_ptr)
 	if (!block_ptr_exist_in_list(bg_lists->booted, bg_record))
 		list_push(bg_lists->booted, bg_record);
-	/* Just incase something happens to free this block before we
+	/* Just in case something happens to free this block before we
 	   start the job we will make it so this job doesn't get blown
 	   away.